pub struct SSLConfigRule {
pub switch: bool,
pub host: String,
pub port: Option<u16>,
}Fields
switch: boolhost: Stringport: Option<u16>Trait Implementations
Sourceimpl Clone for SSLConfigRule
impl Clone for SSLConfigRule
Sourcefn clone(&self) -> SSLConfigRule
fn clone(&self) -> SSLConfigRule
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SSLConfigRule
impl Debug for SSLConfigRule
Sourceimpl<'de> Deserialize<'de> for SSLConfigRule
impl<'de> Deserialize<'de> for SSLConfigRule
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SSLConfigRule
impl JsonSchema for SSLConfigRule
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SSLConfigRule
impl PartialEq for SSLConfigRule
Sourceimpl Serialize for SSLConfigRule
impl Serialize for SSLConfigRule
impl Eq for SSLConfigRule
impl StructuralPartialEq for SSLConfigRule